@@ -1,6 +1,6 @@
 /*
   fread.c -- test cases for reading from zip archives
-  Copyright (C) 2004-2016 Dieter Baron and Thomas Klausner
+  Copyright (C) 2004-2019 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
   The authors can be contacted at <libzip@nih.at>
@@ -17,7 +17,7 @@
   3. The names of the authors may not be used to endorse or promote
      products derived from this software without specific prior
      written permission.
- 
+
   THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
   OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -33,12 +33,8 @@
 
 #include "config.h"
 
-#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
 
 #ifndef HAVE_GETOPT
 #include "getopt.h"
@@ -46,24 +42,19 @@
 
 #include "zip.h"
 
-enum when {
-    WHEN_NEVER, WHEN_OPEN, WHEN_READ, WHEN_CLOSE
-};
+enum when { WHEN_NEVER, WHEN_OPEN, WHEN_READ, WHEN_CLOSE };
 
-const char *when_name[] = {
-    "no", "zip_fopen", "zip_fread", "zip_fclose"
-};
+const char *when_name[] = {"no", "zip_fopen", "zip_fread", "zip_fclose"};
 
 static int do_read(zip_t *z, const char *name, zip_flags_t flags, enum when when_ex, int ze_ex, int se_ex);
 
 int verbose;
 
-const char *prg;
+const char *progname;
 #define USAGE "usage: %s [-v] archive\n"
 
 int
-main(int argc, char *argv[])
-{
+main(int argc, char *argv[]) {
     int fail, ze;
     int c;
     zip_t *z;
@@ -74,32 +65,32 @@ main(int argc, char *argv[])
     verbose = 0;
     fail = 0;
 
-    prg = argv[0];
+    progname = argv[0];
 
-    while ((c=getopt(argc, argv, "v")) != -1) {
+    while ((c = getopt(argc, argv, "v")) != -1) {
 	switch (c) {
-            case 'v':
-                verbose = 1;
-                break;
+	case 'v':
+	    verbose = 1;
+	    break;
 
-            default:
-                fprintf(stderr, USAGE, prg);
-                return 1;
+	default:
+	    fprintf(stderr, USAGE, progname);
+	    return 1;
 	}
     }
 
-    
-    if (argc-optind != 1) {
-        fprintf(stderr, USAGE, prg);
-        return 1;
+
+    if (argc - optind != 1) {
+	fprintf(stderr, USAGE, progname);
+	return 1;
     }
 
     archive = argv[optind];
 
-    if ((z=zip_open(archive, 0, &ze)) == NULL) {
+    if ((z = zip_open(archive, 0, &ze)) == NULL) {
 	zip_error_t error;
 	zip_error_init_with_code(&error, ze);
-	fprintf(stderr, "%s: can't open zip archive '%s': %s\n", prg, archive, zip_error_strerror(&error));
+	fprintf(stderr, "%s: can't open zip archive '%s': %s\n", progname, archive, zip_error_strerror(&error));
 	zip_error_fini(&error);
 	return 1;
     }
@@ -109,9 +100,11 @@ main(int argc, char *argv[])
     fail += do_read(z, "storedcrcerror", 0, WHEN_READ, ZIP_ER_CRC, 0);
     fail += do_read(z, "deflatecrcerror", 0, WHEN_READ, ZIP_ER_CRC, 0);
     fail += do_read(z, "deflatezliberror", 0, WHEN_READ, ZIP_ER_ZLIB, -3);
+#ifndef __clang_analyzer__ /* This test intentionally violates nullability. */
     fail += do_read(z, NULL, 0, WHEN_OPEN, ZIP_ER_INVAL, 0);
+#endif
     fail += do_read(z, "nosuchfile", 0, WHEN_OPEN, ZIP_ER_NOENT, 0);
-    fail += do_read(z, "deflatezliberror", ZIP_FL_COMPRESSED, WHEN_NEVER, 0,0);
+    fail += do_read(z, "deflatezliberror", ZIP_FL_COMPRESSED, WHEN_NEVER, 0, 0);
     fail += do_read(z, "deflatecrcerror", ZIP_FL_COMPRESSED, WHEN_NEVER, 0, 0);
     fail += do_read(z, "storedcrcerror", ZIP_FL_COMPRESSED, WHEN_READ, ZIP_ER_CRC, 0);
     fail += do_read(z, "storedok", ZIP_FL_COMPRESSED, WHEN_NEVER, 0, 0);
@@ -125,46 +118,46 @@ main(int argc, char *argv[])
 
     zs = zip_source_buffer(z, "asdf", 4, 0);
     if ((idx = zip_name_locate(z, "storedok", 0)) < 0) {
-        fprintf(stderr, "%s: can't locate 'storedok' in zip archive '%s': %s\n", prg, archive, zip_strerror(z));
-        fail++;
+	fprintf(stderr, "%s: can't locate 'storedok' in zip archive '%s': %s\n", progname, archive, zip_strerror(z));
+	fail++;
     }
     else {
-        if (zip_replace(z, (zip_uint64_t)idx, zs) < 0) {
-            fprintf(stderr, "%s: can't replace 'storedok' in zip archive '%s': %s\n", prg, archive, zip_strerror(z));
-            fail++;
-        }
-        else {
-            fail += do_read(z, "storedok", 0, WHEN_OPEN, ZIP_ER_CHANGED, 0);
-            fail += do_read(z, "storedok", ZIP_FL_UNCHANGED, WHEN_NEVER, 0, 0);
-        }
+	if (zip_replace(z, (zip_uint64_t)idx, zs) < 0) {
+	    fprintf(stderr, "%s: can't replace 'storedok' in zip archive '%s': %s\n", progname, archive, zip_strerror(z));
+	    fail++;
+	}
+	else {
+	    fail += do_read(z, "storedok", 0, WHEN_OPEN, ZIP_ER_CHANGED, 0);
+	    fail += do_read(z, "storedok", ZIP_FL_UNCHANGED, WHEN_NEVER, 0, 0);
+	}
     }
     if ((idx = zip_name_locate(z, "storedok", 0)) < 0) {
-        fprintf(stderr, "%s: can't locate 'storedok' in zip archive '%s': %s\n", prg, archive, zip_strerror(z));
-        fail++;
+	fprintf(stderr, "%s: can't locate 'storedok' in zip archive '%s': %s\n", progname, archive, zip_strerror(z));
+	fail++;
     }
     else {
-        if (zip_delete(z, (zip_uint64_t)idx) < 0) {
-            fprintf(stderr, "%s: can't replace 'storedok' in zip archive '%s': %s\n", prg, archive, zip_strerror(z));
-            fail++;
-        }
-        else {
-            fail += do_read(z, "storedok", 0, WHEN_OPEN, ZIP_ER_NOENT, 0);
-            fail += do_read(z, "storedok", ZIP_FL_UNCHANGED, WHEN_NEVER, 0, 0);
-        }
+	if (zip_delete(z, (zip_uint64_t)idx) < 0) {
+	    fprintf(stderr, "%s: can't replace 'storedok' in zip archive '%s': %s\n", progname, archive, zip_strerror(z));
+	    fail++;
+	}
+	else {
+	    fail += do_read(z, "storedok", 0, WHEN_OPEN, ZIP_ER_NOENT, 0);
+	    fail += do_read(z, "storedok", ZIP_FL_UNCHANGED, WHEN_NEVER, 0, 0);
+	}
     }
     zs = zip_source_buffer(z, "asdf", 4, 0);
     if (zip_file_add(z, "new_file", zs, 0) < 0) {
-        fprintf(stderr, "%s: can't add file to zip archive '%s': %s\n", prg, archive, zip_strerror(z));
-        fail++;
+	fprintf(stderr, "%s: can't add file to zip archive '%s': %s\n", progname, archive, zip_strerror(z));
+	fail++;
     }
     else {
-        fail += do_read(z, "new_file", 0, WHEN_OPEN, ZIP_ER_CHANGED, 0);
+	fail += do_read(z, "new_file", 0, WHEN_OPEN, ZIP_ER_CHANGED, 0);
     }
-    
+
     zip_unchange_all(z);
     if (zip_close(z) == -1) {
-        fprintf(stderr, "%s: can't close zip archive '%s': %s\n", prg, archive, zip_strerror(z));
-        return 1;
+	fprintf(stderr, "%s: can't close zip archive '%s': %s\n", progname, archive, zip_strerror(z));
+	return 1;
     }
 
     exit(fail ? 1 : 0);
@@ -172,8 +165,7 @@ main(int argc, char *argv[])
 
 
 static int
-do_read(zip_t *z, const char *name, zip_flags_t flags, enum when when_ex, int ze_ex, int se_ex)
-{
+do_read(zip_t *z, const char *name, zip_flags_t flags, enum when when_ex, int ze_ex, int se_ex) {
     zip_file_t *zf;
     enum when when_got;
     zip_error_t error_got, error_ex;
@@ -186,14 +178,14 @@ do_read(zip_t *z, const char *name, zip_flags_t flags, enum when when_ex, int ze
     zip_error_init(&error_got);
     zip_error_init(&error_ex);
     zip_error_set(&error_ex, ze_ex, se_ex);
-    
-    if ((zf=zip_fopen(z, name, flags)) == NULL) {
+
+    if ((zf = zip_fopen(z, name, flags)) == NULL) {
 	when_got = WHEN_OPEN;
 	zf_error = zip_get_error(z);
 	zip_error_set(&error_got, zip_error_code_zip(zf_error), zip_error_code_system(zf_error));
     }
     else {
-	while ((n=zip_fread(zf, b, sizeof(b))) > 0)
+	while ((n = zip_fread(zf, b, sizeof(b))) > 0)
 	    ;
 	if (n < 0) {
 	    when_got = WHEN_READ;
@@ -208,16 +200,13 @@ do_read(zip_t *z, const char *name, zip_flags_t flags, enum when when_ex, int ze
     }
 
     if (when_got != when_ex || zip_error_code_zip(&error_got) != zip_error_code_zip(&error_ex) || zip_error_code_system(&error_got) != zip_error_code_system(&error_ex)) {
-	printf("%s: %s: got %s error (%s), expected %s error (%s)\n",
-	       prg, name,
-	       when_name[when_got], zip_error_strerror(&error_got), 
-	       when_name[when_ex], zip_error_strerror(&error_ex));
+	printf("%s: %s: got %s error (%s), expected %s error (%s)\n", progname, name, when_name[when_got], zip_error_strerror(&error_got), when_name[when_ex], zip_error_strerror(&error_ex));
 	zip_error_fini(&error_got);
 	zip_error_fini(&error_ex);
 	return 1;
     }
     else if (verbose)
-	printf("%s: %s: passed\n", prg, name);
+	printf("%s: %s: passed\n", progname, name);
 
     return 0;
 }
